@@ -1,27 +1,39 @@
 <?php
 /* vim: set expandtab tabstop=4 shiftwidth=4: */
-//
-// +----------------------------------------------------------------------+
-// | PHP Version 4                                                        |
-// +----------------------------------------------------------------------+
-// | Copyright (c) 1997-2002 The PHP Group                                |
-// +----------------------------------------------------------------------+
-// | This source file is subject to version 2.02 of the PHP license,      |
-// | that is bundled with this package in the file LICENSE, and is        |
-// | available at through the world-wide-web at                           |
-// | http://www.php.net/license/3_0.txt.                                  |
-// | If you did not receive a copy of the PHP license and are unable to   |
-// | obtain it through the world-wide-web, please send a note to          |
-// | license@php.net so we can mail you a copy immediately.               |
-// +----------------------------------------------------------------------+
-// | Authors: Harry Fuecks <hfuecks@phppatterns.com>                      |
-// +----------------------------------------------------------------------+
-//
-// $Id: Validator.php 2 2007-11-03 04:59:01Z fishbone $
-//
+
 /**
- * @package Calendar
- * @version $Id: Validator.php 2 2007-11-03 04:59:01Z fishbone $
+ * Contains the Calendar_Validator class
+ *
+ * PHP versions 4 and 5
+ *
+ * LICENSE: Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions are met:
+ * 1. Redistributions of source code must retain the above copyright
+ *    notice, this list of conditions and the following disclaimer.
+ * 2. Redistributions in binary form must reproduce the above copyright
+ *    notice, this list of conditions and the following disclaimer in the
+ *    documentation and/or other materials provided with the distribution.
+ * 3. The name of the author may not be used to endorse or promote products
+ *    derived from this software without specific prior written permission.
+ *
+ * THIS SOFTWARE IS PROVIDED BY THE AUTHOR "AS IS" AND ANY EXPRESS OR IMPLIED
+ * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
+ * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
+ * IN NO EVENT SHALL THE FREEBSD PROJECT OR CONTRIBUTORS BE LIABLE FOR ANY
+ * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
+ * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
+ * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
+ * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
+ * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
+ * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+ *
+ * @category  Date and Time
+ * @package   Calendar
+ * @author    Harry Fuecks <hfuecks@phppatterns.com>
+ * @copyright 2003-2007 Harry Fuecks
+ * @license   http://www.debian.org/misc/bsd.license  BSD License (3 Clause)
+ * @version   CVS: $Id: Validator.php 4940 2012-06-06 02:20:28Z fishbone $
+ * @link      http://pear.php.net/package/Calendar
  */
 
 /**
@@ -37,9 +49,15 @@ if (!defined('CALENDAR_VALUE_TOOLARGE')) {
 /**
  * Used to validate any given Calendar date object. Instances of this class
  * can be obtained from any data object using the getValidator method
- * @see Calendar::getValidator()
- * @package Calendar
- * @access public
+ *
+ * @category  Date and Time
+ * @package   Calendar
+ * @author    Harry Fuecks <hfuecks@phppatterns.com>
+ * @copyright 2003-2007 Harry Fuecks
+ * @license   http://www.debian.org/misc/bsd.license  BSD License (3 Clause)
+ * @link      http://pear.php.net/package/Calendar
+ * @see       Calendar::getValidator()
+ * @access    public
  */
 class Calendar_Validator
 {
@@ -66,17 +84,21 @@ class Calendar_Validator
 
     /**
      * Constructs Calendar_Validator
-     * @param object subclass of Calendar
+     *
+     * @param object &$calendar subclass of Calendar
+     *
      * @access public
      */
-    function Calendar_Validator(& $calendar)
+//    function Calendar_Validator(&$calendar)
+	function __construct(&$calendar)
     {
         $this->calendar = & $calendar;
-        $this->cE = & $calendar->getEngine();
+        $this->cE       = & $calendar->getEngine();
     }
 
     /**
      * Calls all the other isValidXXX() methods in the validator
+     *
      * @return boolean
      * @access public
      */
@@ -84,7 +106,7 @@ class Calendar_Validator
     {
         $checks = array('isValidYear', 'isValidMonth', 'isValidDay',
             'isValidHour', 'isValidMinute', 'isValidSecond');
-        $valid = true;
+        $valid  = true;
         foreach ($checks as $check) {
             if (!$this->{$check}()) {
                 $valid = false;
@@ -95,15 +117,16 @@ class Calendar_Validator
 
     /**
      * Check whether this is a valid year
+     *
      * @return boolean
      * @access public
      */
     function isValidYear()
     {
-        $y = $this->calendar->thisYear();
+        $y   = $this->calendar->thisYear();
         $min = $this->cE->getMinYears();
         if ($min > $y) {
-           $this->errors[] = new Calendar_Validation_Error(
+            $this->errors[] = new Calendar_Validation_Error(
                 'Year', $y, CALENDAR_VALUE_TOOSMALL.$min);
             return false;
         }
@@ -118,12 +141,13 @@ class Calendar_Validator
 
     /**
      * Check whether this is a valid month
+     *
      * @return boolean
      * @access public
      */
     function isValidMonth()
     {
-        $m = $this->calendar->thisMonth();
+        $m   = $this->calendar->thisMonth();
         $min = 1;
         if ($min > $m) {
             $this->errors[] = new Calendar_Validation_Error(
@@ -141,12 +165,13 @@ class Calendar_Validator
 
     /**
      * Check whether this is a valid day
+     *
      * @return boolean
      * @access public
      */
     function isValidDay()
     {
-        $d = $this->calendar->thisDay();
+        $d   = $this->calendar->thisDay();
         $min = 1;
         if ($min > $d) {
             $this->errors[] = new Calendar_Validation_Error(
@@ -154,7 +179,9 @@ class Calendar_Validator
             return false;
         }
         $max = $this->cE->getDaysInMonth(
-            $this->calendar->thisYear(), $this->calendar->thisMonth());
+            $this->calendar->thisYear(), 
+            $this->calendar->thisMonth()
+        );
         if ($d > $max) {
             $this->errors[] = new Calendar_Validation_Error(
                 'Day', $d, CALENDAR_VALUE_TOOLARGE.$max);
@@ -165,12 +192,13 @@ class Calendar_Validator
 
     /**
      * Check whether this is a valid hour
+     *
      * @return boolean
      * @access public
      */
     function isValidHour()
     {
-        $h = $this->calendar->thisHour();
+        $h   = $this->calendar->thisHour();
         $min = 0;
         if ($min > $h) {
             $this->errors[] = new Calendar_Validation_Error(
@@ -188,12 +216,13 @@ class Calendar_Validator
 
     /**
      * Check whether this is a valid minute
+     *
      * @return boolean
      * @access public
      */
     function isValidMinute()
     {
-        $i = $this->calendar->thisMinute();
+        $i   = $this->calendar->thisMinute();
         $min = 0;
         if ($min > $i) {
             $this->errors[] = new Calendar_Validation_Error(
@@ -211,12 +240,13 @@ class Calendar_Validator
 
     /**
      * Check whether this is a valid second
+     *
      * @return boolean
      * @access public
      */
     function isValidSecond()
     {
-        $s = $this->calendar->thisSecond();
+        $s   = $this->calendar->thisSecond();
         $min = 0;
         if ($min > $s) {
             $this->errors[] = new Calendar_Validation_Error(
@@ -234,26 +264,43 @@ class Calendar_Validator
 
     /**
      * Iterates over any validation errors
+     *
      * @return mixed either Calendar_Validation_Error or false
      * @access public
      */
     function fetch()
     {
-        $error = each ($this->errors);
+/*        $error = each($this->errors);
         if ($error) {
             return $error['value'];
         } else {
             reset($this->errors);
             return false;
-        }
+        }*/
+		// PHP7.2非奨励のeach()を置き換え
+		$key = key($this->errors);
+		if ($key){
+			$value = $this->errors[$key];
+			next($this->errors);
+			return $value;
+		} else {
+			reset($this->errors);
+			return false;
+		}
     }
 }
 
 /**
  * For Validation Error messages
- * @see Calendar::fetch()
- * @package Calendar
- * @access public
+ *
+ * @category  Date and Time
+ * @package   Calendar
+ * @author    Harry Fuecks <hfuecks@phppatterns.com>
+ * @copyright 2003-2007 Harry Fuecks
+ * @license   http://www.debian.org/misc/bsd.license  BSD License (3 Clause)
+ * @link      http://pear.php.net/package/Calendar
+ * @see       Calendar::fetch()
+ * @access    public
  */
 class Calendar_Validation_Error
 {
@@ -280,12 +327,14 @@ class Calendar_Validation_Error
 
     /**
      * Constructs Calendar_Validation_Error
-     * @param string Date unit (e.g. month,hour,second)
-     * @param int Value of unit which failed test
-     * @param string Validation error message
+     *
+     * @param string $unit    Date unit (e.g. month,hour,second)
+     * @param int    $value   Value of unit which failed test
+     * @param string $message Validation error message
+     *
      * @access protected
      */
-    function Calendar_Validation_Error($unit,$value,$message)
+    function Calendar_Validation_Error($unit, $value, $message)
     {
         $this->unit    = $unit;
         $this->value   = $value;
@@ -294,6 +343,7 @@ class Calendar_Validation_Error
 
     /**
      * Returns the Date unit
+     *
      * @return string
      * @access public
      */
@@ -304,6 +354,7 @@ class Calendar_Validation_Error
 
     /**
      * Returns the value of the unit
+     *
      * @return int
      * @access public
      */
@@ -314,6 +365,7 @@ class Calendar_Validation_Error
 
     /**
      * Returns the validation error message
+     *
      * @return string
      * @access public
      */
@@ -324,6 +376,7 @@ class Calendar_Validation_Error
 
     /**
      * Returns a string containing the unit, value and error message
+     *
      * @return string
      * @access public
      */
