@@ -8,7 +8,7 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2017 Magic3 Project.
+ * @copyright  Copyright 2006-2018 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
  * @version    SVN: $Id$
  * @link       http://www.magic3.org
@@ -552,6 +552,7 @@ $agent = 'Mozilla/5.0 (Windows NT 10.0; WOW64) AppleWebKit/537.36 (KHTML, like G
 			'scej psp browser'				=> '',	// ワイプアウトピュア
 			'w3m'							=> '',
 			'netcaptor'						=> 'netcaptor.gif',
+			'netcraft'						=> 'netcraft.png',
 			'webtv'							=> 'webtv.gif',
 			'vivaldi'						=> 'vivaldi.png',
 			
@@ -570,6 +571,7 @@ $agent = 'Mozilla/5.0 (Windows NT 10.0; WOW64) AppleWebKit/537.36 (KHTML, like G
 			'simplepie'						=> 'simplepie.png',
 			
 			// クローラー
+			'applebot'					=> 'applebot.png',
 			'googlebot'					=> 'google.gif',	// Google
 			'googlebot-mobile'			=> 'google.gif',	// Google-Mobile
 			'mediapartners-google'		=> 'google.gif',	// Google
