@@ -8,7 +8,7 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2016 Magic3 Project.
+ * @copyright  Copyright 2006-2018 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
  * @version    SVN: $Id$
  * @link       http://www.magic3.org
@@ -41,6 +41,37 @@ class admin_analyzeDb extends BaseDb
 		$ret = $this->selectRecord($queryStr, array($serial), $row);
 		return $ret;
 	}
+	/**
+	 * 最も古いサイト解析ページビューを取得
+	 *
+	 * @param array  	$row		取得レコード
+	 * @param bool					true=成功、false=失敗
+	 */
+	function getOldPageView(&$row)
+	{
+		$serial = 0;
+		$queryStr  = 'SELECT min(ap_serial) as m FROM _analyze_page_view ';
+		$ret = $this->selectRecord($queryStr, array(), $row);
+		if ($ret) $serial = $row['m'];
+		
+		$queryStr  = 'SELECT * FROM _analyze_page_view ';
+		$queryStr .=   'WHERE ap_serial = ?';
+		$ret = $this->selectRecord($queryStr, array($serial), $row);
+		return $ret;
+	}
+	/**
+	 * アクセスログを削除
+	 *
+	 * @param timestamp	$startDt	最初の未集計日
+	 * @return						true=成功、false=失敗
+	 */
+	function delAccessLog($startDt)
+	{
+		$queryStr = 'DELETE FROM _access_log WHERE al_dt < ?';
+		$params = array($startDt);
+		$ret = $this->execStatement($queryStr, $params);
+		return $ret;
+	}
 	/**
 	 * サイト解析状況を更新
 	 *
