@@ -8,7 +8,7 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2014 Magic3 Project.
+ * @copyright  Copyright 2006-2018 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
  * @version    SVN: $Id$
  * @link       http://www.magic3.org
@@ -79,7 +79,8 @@ class default_menuWidgetContainer extends BaseWidgetContainer
 			case 0:
 				$this->renderType = 'JOOMLA_OLD';
 				break;
-			case 10:
+			case 10:	// Bootstrap v3.0
+			case 11:	// Bootstrap v4.0
 				if ($isNav){
 					$this->renderType = 'BOOTSTRAP_NAV';		// Boostrapナビゲーションメニュー
 				} else {
@@ -105,7 +106,11 @@ class default_menuWidgetContainer extends BaseWidgetContainer
 				$templateFile = 'index_old.tmpl.html';
 				break;
 			case 'BOOTSTRAP_NAV':		// Bootstrapナビゲーションメニュー
-				$templateFile = 'index_bootstrap_nav.tmpl.html';
+				if ($this->templateType == 10){	// Bootstrap v3.0のとき
+					$templateFile = 'index_bootstrap_nav.tmpl.html';
+				} else {	// Bootstrap v4.0のとき
+					$templateFile = 'index_bootstrap_nav4.tmpl.html';
+				}
 				
 				// CSSファイルの追加
 				$this->cssFilePath[] = $this->getUrl($this->gEnv->getCurrentWidgetCssUrl() . self::DEFAULT_BOOTSTRAP_CSS_FILE);		// CSSファイル
@@ -145,7 +150,7 @@ class default_menuWidgetContainer extends BaseWidgetContainer
 		
 		$menuId		= $targetObj->menuId;	// メニューID
 		$name		= $targetObj->name;// 定義名
-		$this->isHierMenu	= $targetObj->isHierMenu;		// 階層化メニューを使用するかどうか
+//		$this->isHierMenu	= $targetObj->isHierMenu;		// 階層化メニューを使用するかどうか
 		$limitUser			= $targetObj->limitUser;// ユーザを制限するかどうか
 		$useVerticalMenu 	= $targetObj->useVerticalMenu;		// 縦型メニューデザインを使用するかどうか
 		$showSitename	= isset($targetObj->showSitename) ? $targetObj->showSitename : 1;		// サイト名を表示するかどうか
@@ -154,6 +159,10 @@ class default_menuWidgetContainer extends BaseWidgetContainer
 		$showRegist		= isset($targetObj->showRegist) ? $targetObj->showRegist : 0;			// 会員登録を表示するかどうか
 		$anotherColor	= isset($targetObj->anotherColor) ? $targetObj->anotherColor : 0;		// 色を変更するかどうか
 		
+		// 階層化メニューを使用するかどうか取得
+		//$this->getMenuInfo($this->isHierMenu, $itemId, $row);
+		$this->isHierMenu = $this->gSystem->isSiteMenuHier();
+		
 		$act = $request->trimValueOf('act');
 		if ($act == 'nav_login'){			// ログインのとき
 			// アカウント、パスワード取得
@@ -215,7 +224,11 @@ class default_menuWidgetContainer extends BaseWidgetContainer
 					
 				// サイト名の表示制御
 				if (!$showSitename){
-					$sitenameOptionClass = ' visible-xs';			// モニタが最小サイズの場合のみ表示
+					if ($this->templateType == 10){	// Bootstrap v3.0のとき
+						$sitenameOptionClass = ' visible-xs';			// モニタが最小サイズの場合のみ表示
+					} else {		// Bootstrap v4.0のとき
+						$sitenameOptionClass = ' d-lg-none';			// モニタが最小サイズの場合のみ表示
+					}
 					$this->tmpl->addVar("_widget", "sitename_option_class", $sitenameOptionClass);
 				}
 				// 検索フィールド表示制御
@@ -257,8 +270,21 @@ class default_menuWidgetContainer extends BaseWidgetContainer
 				// メニュー属性を取得
 				if (!empty($menuAttr['bootstyle'])) $navbarOptionClass[] = $menuAttr['bootstyle'];
 				
-				// 別の色を指定の場合
-				if ($anotherColor) $navbarOptionClass[] = 'navbar-inverse';
+				// メニューバーの色を設定
+				if ($this->templateType == 10){	// Bootstrap v3.0のとき
+					if ($anotherColor) $navbarOptionClass[] = 'navbar-inverse';
+				} else {		// Bootstrap v4.0のとき
+					// 折り返しポイントを設定。サイト名の表示制御「d-lg-none」と連携。
+					$navbarOptionClass[] = 'navbar-expand-lg';
+					
+					if ($anotherColor){		// 別の色を指定の場合
+						$navbarOptionClass[] = 'navbar-dark';
+						$navbarOptionClass[] = 'bg-dark';
+					} else {			// デフォルトカラー
+						$navbarOptionClass[] = 'navbar-light';
+						$navbarOptionClass[] = 'bg-light';
+					}
+				}
 
 				// データを画面に埋め込む
 				if (!empty($navbarOptionClass)) $this->tmpl->addVar("_widget", "navbar_option_class", ' ' . implode(' ', $navbarOptionClass));
@@ -325,8 +351,8 @@ class default_menuWidgetContainer extends BaseWidgetContainer
 			$itemCount = count($rows);
 			for ($i = 0; $i < $itemCount; $i++){
 				$row = $rows[$i];
-				$classArray = array();
-				$linkClassArray = array();
+				$classArray = array();		// 項目のクラス
+				$linkClassArray = array();	// リンクタグのクラス
 				$attr = '';
 				// Joomla用メニューデータ(デフォルト値)
 				$menuItem = new stdClass;		// Joomla用メニューデータ
@@ -382,6 +408,16 @@ class default_menuWidgetContainer extends BaseWidgetContainer
 				}
 				
 				// リンクタイプに合わせてタグを生成
+				// ### メニューがナビゲーションタイプの場合はテンプレートタイプに合わせたクラスを出力する。ナビゲーションタイプでない場合はプレーンなUL,LIタグを出力する。###
+				if ($this->renderType == 'BOOTSTRAP_NAV'){// Bootstrapナビゲーションメニューのとき
+					if ($this->templateType == 11){// Bootstrap v4.0のとき
+						if ($level == 0){		// 1階層目の場合
+							array_unshift($linkClassArray, 'nav-link');
+						} else {			// 2階層目以下の場合
+							array_unshift($linkClassArray, 'dropdown-item');
+						}
+					}
+				}
 				$linkOption = '';
 				if (count($linkClassArray) > 0) $linkOption .= 'class="' . implode(' ', $linkClassArray) . '"';
 				switch ($row['md_link_type']){
@@ -420,8 +456,14 @@ class default_menuWidgetContainer extends BaseWidgetContainer
 						$this->menuTree[] = $menuItem;
 						
 						// ##### タグ作成 #####
+						// ### メニューがナビゲーションタイプの場合はテンプレートタイプに合わせたクラスを出力する。ナビゲーションタイプでない場合はプレーンなUL,LIタグを出力する。###
+						if ($this->renderType == 'BOOTSTRAP_NAV'){// Bootstrapナビゲーションメニューのとき
+							if ($this->templateType == 11){				// Bootstrap v4.0のとき
+								if ($level == 0) array_unshift($classArray, 'nav-item');		// 1階層目の場合
+							}
+						}
+				
 						if (count($classArray) > 0) $attr .= ' class="' . implode(' ', $classArray) . '"';
-						//$treeHtml .= '<li' . $attr . '><a href="' . $this->convertUrlToHtmlEntity($linkUrl) . '" ' . $linkOption . '><span>' . $this->convertToDispString($name) . '</span></a></li>' . M3_NL;
 						$treeHtml .= '<li' . $attr . '><a href="' . $this->convertUrlToHtmlEntity($linkUrl) . '" ' . $linkOption . '><span>' . $title . '</span></a></li>' . M3_NL;
 						break;
 					case 1:			// フォルダのとき
@@ -443,29 +485,47 @@ class default_menuWidgetContainer extends BaseWidgetContainer
 							array_push($parentTree, $index);
 							
 							// サブメニュー作成
-							$menuText = $this->createMenu($menuId, $row['md_id'], $level + 1, $hasSelectedChild, $parentTree);
+							$menuText = $this->createMenu($menuId, $row['md_id'], $level + 1, $hasSelectedChildSub, $parentTree);
+							if ($hasSelectedChildSub) $hasSelectedChild = true;			// さらに子孫が選択状態にあるときは現在の位置の状態を更新
 							
 							// 階層を戻す
 							array_pop($parentTree);
 							
 							// 子項目が選択中のときは「active」に設定
-							if ($hasSelectedChild) $classArray[] = 'active';
+							if ($hasSelectedChildSub) $classArray[] = 'active';
 
 							// 先頭に「parent」クラスを追加
 							array_unshift($classArray, 'parent');
 							
 							// ##### タグ作成 #####
+							// ### メニューがナビゲーションタイプの場合はテンプレートタイプに合わせたクラスを出力する。ナビゲーションタイプでない場合はプレーンなUL,LIタグを出力する。###
 							if ($this->renderType == 'BOOTSTRAP_NAV'){// Bootstrapナビゲーションメニューのとき
-								//$classArray[] = 'dropdown';
 								$dropDownCaret = '';
-								if ($level == 0){
-									$dropDownCaret = ' <b class="caret"></b>';
-								} else {
-									$classArray[] = 'dropdown-submenu';
+								
+								if ($this->templateType == 10){	// Bootstrap v3.0のとき
+									if ($level == 0){
+										$dropDownCaret = ' <b class="caret"></b>';
+									} else {
+										$classArray[] = 'dropdown-submenu';
+									}
+								} else {		// Bootstrap v4.0のとき
+									if ($level == 0){		// 1階層目の場合
+										array_unshift($classArray, 'nav-item dropdown');
+									} else {			// 2階層目以下の場合
+										array_unshift($classArray, 'dropdown-submenu');
+									}
 								}
 								
+								$linkClassArray[] = 'dropdown-toggle';
+								
+								// 子項目が選択中のときは「active」に設定
+								if ($hasSelectedChildSub) $linkClassArray[] = 'active';
+
+								$linkOption = '';
+								if (count($linkClassArray) > 0) $linkOption .= 'class="' . implode(' ', $linkClassArray) . '"';
+									
 								if (count($classArray) > 0) $attr .= ' class="' . implode(' ', $classArray) . '"';
-								$treeHtml .= '<li' . $attr . '><a href="' . $this->convertUrlToHtmlEntity($linkUrl) . '" class="dropdown-toggle" data-toggle="dropdown"><span>' . $title . $dropDownCaret . '</span></a>' . M3_NL;
+								$treeHtml .= '<li' . $attr . '><a href="' . $this->convertUrlToHtmlEntity($linkUrl) . '" ' . $linkOption . ' data-toggle="dropdown"><span>' . $title . $dropDownCaret . '</span></a>' . M3_NL;
 								if (!empty($menuText)){
 									$treeHtml .= '<ul class="dropdown-menu">' . M3_NL;
 									$treeHtml .= $menuText;
