@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2012 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: ec_mainDeliveryWidgetContainer.php 5440 2012-12-08 09:37:39Z fishbone $
+ * @version    SVN: $Id: ec_mainDeliveryWidgetContainer.php 5572 2013-01-23 08:43:39Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getCurrentWidgetContainerPath() .	'/ec_mainBaseWidgetContainer.php');
@@ -64,11 +64,15 @@ class ec_mainDeliveryWidgetContainer extends ec_mainBaseWidgetContainer
 		$address2 = $request->trimValueOf('item_address2');	// 住所
 		$phone = $request->trimValueOf('item_phone');	// 電話番号
 //		$fax = $request->trimValueOf('item_fax');	// FAX
-//		$email = $request->trimValueOf('item_email');	// Email
-//		$email2 = $request->trimValueOf('item_email2');	// Email確認用
 		$this->addressId = $request->trimValueOf('item_addressid');	// コピー用に選択した住所ID
 //		$demandDt = $request->trimValueOf('item_demand_dt');		// 配達希望日
 		
+		// ##### 非会員の購入の場合はEメールを入力 #####
+		if (empty($this->_userId)){			// 非会員の購入の場合
+			$email = $request->trimValueOf('item_email');	// Email
+			$email2 = $request->trimValueOf('item_email2');	// Email確認用
+		}
+
 		$act = $request->trimValueOf('act');
 		if ($act == 'regist'){			// 配送先仮登録
 			$this->checkInput($name, '名前');		
@@ -78,6 +82,16 @@ class ec_mainDeliveryWidgetContainer extends ec_mainBaseWidgetContainer
 			$this->checkInput($address, '住所');	
 			$this->checkSingleByte($phone, '電話番号');
 			
+			// ##### 非会員の購入の場合はEメールを入力 #####
+			if (empty($this->_userId)){
+				$this->checkMailAddress($email, 'Eメール');
+				$this->checkMailAddress($email2, 'Eメール(確認)');
+				
+				if ($this->getMsgCount() == 0){			// メールアドレスのチェック
+					if ($email != $email2) $this->setAppErrorMsg('Eメールアドレスに誤りがあります');
+				}
+			}
+			
 			// エラーなしの場合
 			if ($this->getMsgCount() == 0){
 				// 注文書を取得
@@ -87,9 +101,39 @@ class ec_mainDeliveryWidgetContainer extends ec_mainBaseWidgetContainer
 					if (empty($this->_userId)){			// 非会員の購入の場合
 						$custm_name = $name;
 						$custm_name_kana = $nameKana;
+						$custm_email = $email;
+						
+						// 請求先を初期化
+						$bill_name = $name;
+						$bill_name_kana = $nameKana;
+						$bill_person = '';
+						$bill_person_kana = '';
+						$bill_zipcode = $this->zipcode;
+						$bill_state_id = $this->state;
+						$bill_address = $address;
+						$bill_address2 = $address2;
+						$bill_phone = $phone;
+						$bill_fax = '';
+						$bill_email = $email;
+						$bill_country_id = '';
 					} else {
 						$custm_name = $row['oe_custm_name'];
 						$custm_name_kana = $row['oe_custm_name_kana'];
+						$custm_email = $row['oe_custm_email'];
+						
+						// 請求先を維持
+						$bill_name = $row['oe_bill_name'];
+						$bill_name_kana = $row['oe_bill_name_kana'];
+						$bill_person = $row['oe_bill_person'];
+						$bill_person_kana = $row['oe_bill_person_kana'];
+						$bill_zipcode = $row['oe_bill_zipcode'];
+						$bill_state_id = $row['oe_bill_state_id'];
+						$bill_address = $row['oe_bill_address1'];
+						$bill_address2 = $row['oe_bill_address2'];
+						$bill_phone = $row['oe_bill_phone'];
+						$bill_fax = $row['oe_bill_fax'];
+						$bill_email = $row['oe_bill_email'];
+						$bill_country_id = $row['oe_bill_country_id'];
 					}
 					
 					// 配送先が更新されている場合は以降の画面で設定するデータの更新の必要があるので一旦データをすべて初期化
@@ -130,10 +174,10 @@ class ec_mainDeliveryWidgetContainer extends ec_mainBaseWidgetContainer
 
 					$ret = self::$_orderDb->updateOrderSheet($this->_userId, $this->_langId, $this->_getClientId(),
 						$row['oe_custm_id'], $custm_name, $custm_name_kana, $row['oe_custm_person'], $row['oe_custm_person_kana'],
-						$row['oe_custm_zipcode'], $row['oe_custm_state_id'], $row['oe_custm_address1'], $row['oe_custm_address2'], $row['oe_custm_phone'], $row['oe_custm_fax'], $row['oe_custm_email'], $row['oe_custm_country_id'], 
+						$row['oe_custm_zipcode'], $row['oe_custm_state_id'], $row['oe_custm_address1'], $row['oe_custm_address2'], $row['oe_custm_phone'], $row['oe_custm_fax'], $custm_email, $row['oe_custm_country_id'], 
 						$deliv_id, $deliv_name, $deliv_name_kana, $deliv_person, $deliv_person_kana, $deliv_zipcode, $deliv_state_id, $deliv_address, $deliv_address2, $deliv_phone, $deliv_fax, $deliv_email, $deliv_country_id,
-						$row['oe_bill_id'], $row['oe_bill_name'], $row['oe_bill_name_kana'], $row['oe_bill_person'], $row['oe_bill_person_kana'], 
-						$row['oe_bill_zipcode'], $row['oe_bill_state_id'], $row['oe_bill_address1'], $row['oe_bill_address2'], $row['oe_bill_phone'], $row['oe_bill_fax'], $row['oe_bill_email'], $row['oe_bill_country_id'],
+						$row['oe_bill_id'], $bill_name, $bill_name_kana, $bill_person, $bill_person_kana, 
+						$bill_zipcode, $bill_state_id, $bill_address, $bill_address2, $bill_phone, $bill_fax, $bill_email, $bill_country_id,
 						$row['oe_deliv_method_id'], $row['oe_pay_method_id'], $row['oe_card_type'], $row['oe_card_owner'], $row['oe_card_number'], $row['oe_card_expires'],
 						$row['oe_demand_dt'], $row['oe_demand_time'], $row['oe_appoint_dt'], $row['oe_currency_id'], $row['oe_subtotal'], $row['oe_discount'], $row['oe_deliv_fee'], $row['oe_charge'], $row['oe_total']);
 					// この画面の登録完了をもって、購入用データは作成済みとする
@@ -147,22 +191,7 @@ class ec_mainDeliveryWidgetContainer extends ec_mainBaseWidgetContainer
 				}
 			}
 		} else if ($act == 'copydata'){			// データコピーのとき
-			if (empty($this->_userId)){			// 非会員の購入の場合
-				if ($this->addressId == '-1'){		// 購入者の情報のとき
-					$ret = self::$_orderDb->getOrderSheetByClientId($this->gAccess->getClientId(), $row);// クライアントIDから登録データを取得
-					if ($ret){
-						$name = $row['oe_custm_name'];
-						$nameKana = $row['oe_custm_name_kana'];
-						$this->zipcode = $row['oe_custm_zipcode'];
-						$address = $row['oe_custm_address1'];
-						$address2 = $row['oe_custm_address2'];
-						$phone = $row['oe_custm_phone'];
-						$this->state = $row['oe_custm_state_id'];
-					} else {
-						self::$_orderDb->delOrderSheetByClientId($this->gAccess->getClientId());		// エラーのときはエラーデータを削除
-					}
-				}
-			} else {				// 会員の購入の場合
+			if (!empty($this->_userId)){			// 会員の購入の場合
 				// 会員情報を取得
 				$ret = self::$_orderDb->getMember($this->_userId, $memberRow);
 				if ($ret){
@@ -196,6 +225,12 @@ class ec_mainDeliveryWidgetContainer extends ec_mainBaseWidgetContainer
 				$phone = $row['oe_deliv_phone'];
 				$this->state = $row['oe_deliv_state_id'];
 //				$demandDt = $row['oe_demand_time'];			// 配達希望日
+
+				// ##### 非会員の購入の場合はEメールを入力 #####
+				if (empty($this->_userId)){
+					$email = $row['oe_custm_email'];	// Email
+					$email2 = $row['oe_custm_email'];	// Email確認用
+				}
 			}
 		}
 		// コピー用メニュー作成
@@ -212,14 +247,18 @@ class ec_mainDeliveryWidgetContainer extends ec_mainBaseWidgetContainer
 		$this->tmpl->addVar("_widget", "address2", $address2);
 		$this->tmpl->addVar("_widget", "phone", $phone);
 //		$this->tmpl->addVar("_widget", "demand_dt", $demandDt);
-		if (!$isCopyMenuActive) $this->tmpl->addVar("_widget", "copymenu_disabled", "disabled");
+		if (!$isCopyMenuActive){
+			//$this->tmpl->addVar("_widget", "copymenu_disabled", "disabled");
+			$this->tmpl->setAttribute('copy_data', 'visibility', 'hidden');		// 住所コピーメニュー隠す
+		}
+		
+		// ##### 非会員の購入の場合はEメールを入力 #####
+		if (empty($this->_userId)){
+			$this->tmpl->setAttribute('input_email', 'visibility', 'visible');
+			$this->tmpl->addVar("input_email", "email", $email);
+			$this->tmpl->addVar("input_email", "email2", $email2);
+		}
 		
-		// 遷移先を設定
-/*		if (empty($this->_userId)){			// 非会員の購入の場合
-			$this->tmpl->addVar("_widget", "goback_url", $this->getUrl($this->gEnv->createCurrentPageUrl() . '&task=regcustomer', true));		// 購入者登録画面
-		} else {		// 会員の購入の場合
-			$this->tmpl->addVar("_widget", "goback_url", $this->getUrl($this->gEnv->createCurrentPageUrl() . '&task=cart', true));		// カート画面
-		}*/
 		$this->tmpl->addVar("_widget", "goback_url", $this->getUrl($this->gEnv->createCurrentPageUrl() . '&task=' . $this->_getOrderNextTask(-1) . '&act=goback', true));		// 1つ前の画面
 	}
 	/**
@@ -231,9 +270,7 @@ class ec_mainDeliveryWidgetContainer extends ec_mainBaseWidgetContainer
 	function createCopyDataMenu($userId)
 	{
 		$menu = array(array(	'name' => '住所をコピー',		'value' => ''));
-		if (empty($userId)){		// ユーザが設定されていないとき
-			$menu[] = array(	'name' => '購入者の住所',	'value' => '-1');
-		} else {
+		if (!empty($userId)){		// ログインユーザの場合
 			$addressArray = $this->getAddressByUserId($userId);
 			for ($i = 0; $i < count($addressArray); $i++){
 				$menu[] = array('name' => $addressArray[$i]['ad_title'],	'value' => $addressArray[$i]['ad_id']);
