@@ -8,7 +8,7 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2015 Magic3 Project.
+ * @copyright  Copyright 2006-2017 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
  * @version    SVN: $Id$
  * @link       http://www.magic3.org
@@ -51,7 +51,7 @@ function plugin_diff_view($page)
 		'<li>' . $_msg_delline . '</li>'
 	);
 	
-	$is_page = is_page($page);
+	$is_page = WikiPage::isPage($page);
 	if ($is_page) {
 		$menu[] = ' <li>' . str_replace('$1', '<a href="' . $script . WikiParam::convQuery("?$r_page") . '">' . $s_page . '</a>', $_msg_goto) . '</li>';
 	} else {	// ページがない場合
